# -*- coding: utf-8 -*-


class HttpVerb(object):
    """
    Constants representing http method verbs. Available values are:

    * yookassa.domain.common.HttpVerb.GET
    * yookassa.domain.common.HttpVerb.POST
    * yookassa.domain.common.HttpVerb.PUT
    * yookassa.domain.common.HttpVerb.PATCH
    * yookassa.domain.common.HttpVerb.HEAD
    * yookassa.domain.common.HttpVerb.OPTIONS
    * yookassa.domain.common.HttpVerb.DELETE
    """
    GET = 'get'
    POST = 'post'
    PUT = 'put'
    PATCH = 'patch'
    HEAD = 'head'
    OPTIONS = 'options'
    DELETE = 'delete'
